@@ -1,24 +1,24 @@
 /*                     __                                               *\
 **     ________ ___   / /  ___     Scala API                            **
-**    / __/ __// _ | / /  / _ |    (c) 2003-2007, LAMP/EPFL             **
+**    / __/ __// _ | / /  / _ |    (c) 2003-2010, LAMP/EPFL             **
 **  __\ \/ /__/ __ |/ /__/ __ |    http://scala-lang.org/               **
 ** /____/\___/_/ |_/____/_/ | |                                         **
 **                          |/                                          **
 \*                                                                      */
 
-// $Id: $
+// $Id: native.scala 21480 2010-04-12 14:38:16Z dubochet $
 
 
 package scala
 
-/**
- * Marker for native methods.
- * <p>
- *   <code>@native def f(x: Int, y: List[Long]): String = ..</code>
- * </p>
- * <p>
- *   Method body is not generated if method is marked with <code>@native</code>,
- *   but it is type checked when present.
- * </p>
- */
-class native extends Annotation {}
+/** Marker for native methods.
+  *
+  * {{{
+  * @native def f(x: Int, y: List[Long]): String = ...
+  * }}}
+  *
+  * Method body is not generated if method is marked with `@native`,
+  * but it is type checked when present.
+  *
+  * @since 2.6 */
+class native extends StaticAnnotation {}
