@@ -1,16 +1,17 @@
 /*                     __                                               *\
 **     ________ ___   / /  ___     Scala API                            **
-**    / __/ __// _ | / /  / _ |    (c) 2002-2008, LAMP/EPFL             **
+**    / __/ __// _ | / /  / _ |    (c) 2002-2010, LAMP/EPFL             **
 **  __\ \/ /__/ __ |/ /__/ __ |    http://scala-lang.org/               **
 ** /____/\___/_/ |_/____/_/ | |                                         **
 **                          |/                                          **
 \*                                                                      */
 
-// $Id: RichLong.scala 13740 2008-01-18 21:20:33Z michelou $
+// $Id: RichLong.scala 20028 2009-12-07 11:49:19Z cunei $
 
 
 package scala.runtime
 
+import scala.collection.immutable.{Range, NumericRange}
 
 final class RichLong(x: Long) extends Proxy with Ordered[Long] {
 
@@ -20,6 +21,19 @@ final class RichLong(x: Long) extends Proxy with Ordered[Long] {
   // Ordered[Long].compare
   def compare(y: Long): Int = if (x < y) -1 else if (x > y) 1 else 0
 
+  /** Create a NumericRange[Long] in range <code>[start;end)</code>
+   *  with the specified step, where start is the target Long.
+   *
+   *  @param end    the end value of the range (exclusive)
+   *  @param step   the distance between elements (defaults to 1)
+   *  @return       the range
+   */
+  def until(end: Long, step: Long = 1L): NumericRange.Exclusive[Long] = Range.Long(x, end, step)
+  
+  /** Like until, but inclusive of the end value.
+   */
+  def to(end: Long, step: Long = 1L): NumericRange.Inclusive[Long] = Range.Long.inclusive(x, end, step)
+
   def min(y: Long): Long = if (x < y) x else y
   def max(y: Long): Long = if (x > y) x else y
   def abs: Long = if (x < 0) -x else x
